==> django_docutils-0.12.0-py3-none-any.whl: django_docutils/views.py <==
from django.core.exceptions import ImproperlyConfigured
from django.template.loader import select_template
from django.template.response import TemplateResponse
from django.views.generic.base import TemplateView


class DocutilsResponse(TemplateResponse):
    template_name = "base.html"

    def __init__(
        self,
        request,
        template,
        rst,
        context=None,
        content_type=None,
        status=None,
        charset=None,
        using=None,
    ):
        self.rst_name = rst
        super().__init__(
            request, template, context, content_type, status, charset, using
        )

    @property
    def rendered_content(self):
        """Return the freshly rendered content for the template and context
        described by the TemplateResponse.

        This *does not* set the final content of the response. To set the
        response content, you must either call render(), or set the
        content explicitly using the value of this property.
        """

        context = self.resolve_context(self.context_data)

        # we should be able to use the engine to .Render this
        from django.utils.safestring import mark_safe

        context["content"] = mark_safe(
            select_template(self.rst_name, using="docutils").render()
        )

        template = self.resolve_template(self.template_name)
        content = template.render(context, self._request)
        return content


class DocutilsViewRstNameImproperlyConfigured(ImproperlyConfigured):
    def __init__(self, *args: object, **kwargs: object) -> None:
        return super().__init__(
            "DocutilsView requires either a definition of 'rst_name' "
            "or an implementation of 'get_rst_names()'",
            *args,
            **kwargs
        )


class DocutilsView(TemplateView):
    response_class = DocutilsResponse
    rst_name = None

    def render_to_response(self, context, **response_kwargs):
        """Override to pay in rst content."""
        return self.response_class(
            request=self.request,
            template=self.get_template_names(),
            rst=self.get_rst_names(),
            context=context,
            using=self.template_engine,
            **response_kwargs
        )

    def get_rst_names(self):
        """
        Follows after get_template_names, but for scanning for rst content.
        """
        if self.rst_name is None:
            raise DocutilsViewRstNameImproperlyConfigured()
        else:
            return [self.rst_name]

==> django_docutils-0.14.1-py3-none-any.whl: django_docutils/views.py <==
import typing as t

from django.core.exceptions import ImproperlyConfigured
from django.http.request import HttpRequest
from django.http.response import HttpResponse
from django.template.loader import select_template
from django.template.response import TemplateResponse
from django.views.generic.base import TemplateView


class DocutilsResponse(TemplateResponse):
    template_name = "base.html"

    def __init__(
        self,
        request: HttpRequest,
        template: list[str],
        rst: list[str],
        context: t.Optional[t.Dict[str, t.Any]] = None,
        content_type: t.Optional[str] = None,
        status: t.Optional[int] = None,
        charset: t.Optional[str] = None,
        using: t.Optional[str] = None,
    ):
        self.rst_name = rst
        super().__init__(
            request, template, context, content_type, status, charset, using
        )

    @property
    def rendered_content(self) -> str:
        """Return the freshly rendered content for the template and context
        described by the TemplateResponse.

        This *does not* set the final content of the response. To set the
        response content, you must either call render(), or set the
        content explicitly using the value of this property.
        """

        context: t.Dict[str, t.Any] = self.resolve_context(self.context_data) or {}

        # we should be able to use the engine to .Render this
        from django.utils.safestring import mark_safe

        context["content"] = mark_safe(
            select_template(self.rst_name, using="docutils").render()
        )

        template = self.resolve_template(self.template_name)
        content = template.render(context)
        return content


class DocutilsViewRstNameImproperlyConfigured(ImproperlyConfigured):
    def __init__(self, *args: object, **kwargs: object) -> None:
        return super().__init__(
            "DocutilsView requires either a definition of 'rst_name' "
            "or an implementation of 'get_rst_names()'",
            *args,
            **kwargs
        )


class DocutilsView(TemplateView):
    response_class = DocutilsResponse
    rst_name = None

    def render_to_response(
        self,
        context: t.Optional[t.Dict[str, t.Any]] = None,
        content_type: t.Optional[str] = None,
        status: t.Optional[int] = None,
        charset: t.Optional[str] = None,
        using: t.Optional[str] = None,
        **response_kwargs: object
    ) -> HttpResponse:
        """Override to pay in rst content."""
        return self.response_class(
            request=self.request,
            template=self.get_template_names(),
            rst=self.get_rst_names(),
            context=context,
            content_type=content_type,
            status=status,
            using=using or self.template_engine,
        )

    def get_rst_names(self) -> list[str]:
        """
        Follows after get_template_names, but for scanning for rst content.
        """
        if self.rst_name is None:
            raise DocutilsViewRstNameImproperlyConfigured()
        else:
            return [self.rst_name]
